@@ -122,12 +122,24 @@ sub try_or_fail {
     return 1;
 }
 
+# Based on Deep::Hash::Utils nest
+sub create_nest {
+    my ($depth) = @_;
+    my $orig = my $hr = {};
+    my @numbers = ( 1 .. $depth );
+    while (my $key = shift @numbers) {
+        $hr->{$key} = @numbers ? {} : undef;
+        $hr = $hr->{$key};
+    }
+    return $orig;
+}
+
 
 1;
 #
 # This file is part of BSON-XS
 #
-# This software is Copyright (c) 2018 by MongoDB, Inc.
+# This software is Copyright (c) 2019 by MongoDB, Inc.
 #
 # This is free software, licensed under:
 #
